@@ -25,6 +25,8 @@ MIDI files:
 
     MidiFile(filename, **kwargs) -- open a MIDI file
     MidiTrack()  -- a MIDI track
+    bpm2tempo()  -- convert beats per minute to MIDI file tempo
+    tempo2bpm()  -- convert MIDI file tempo to beats per minute
 
 SYX files:
 
@@ -93,13 +95,14 @@ from .messages import Message
 from .messages import parse_string, parse_string_stream, format_as_string
 from .parser import Parser, parse, parse_all
 from .midifiles import MidiFile, MidiTrack, MetaMessage
+from .midifiles_meta import bpm2tempo, tempo2bpm
 from .syx import read_syx_file, write_syx_file
 
 __author__ = 'Ole Martin Bjorndalen'
 __email__ = 'ombdalen@gmail.com'
 __url__ = 'http://mido.readthedocs.org/'
 __license__ = 'MIT'
-__version__ = '1.1.10'
+__version__ = '1.1.11'
 
 # Prevent splat import.
 __all__ = []
