@@ -29,10 +29,9 @@ import timeit
 import string
 from contextlib import contextmanager
 from .ports import BaseOutput
-from .types import encode_variable_int
 from .messages import build_message, Message, get_spec
 from .midifiles_meta import MetaMessage, _build_meta_message, meta_charset
-from .midifiles_meta import MetaSpec, add_meta_spec
+from .midifiles_meta import MetaSpec, add_meta_spec, encode_variable_int
 from . import midifiles_meta
 
 # The default tempo is 120 BPM.
@@ -163,26 +162,6 @@ class MidiTrack(list):
         return '<midi track {!r} {} messages>'.format(self.name, len(self))
 
 
-def _merge_tracks(tracks):
-    """Merge all messates from tracks.
-
-    Delta times are converted to absolute time (in ticks), and
-    messages from all tracks are sorted on absolute time.
-    """
-    messages = []
-    for i, track in enumerate(tracks):
-        now = 0
-        for message in track:
-            now += message.time
-            messages.append(message.copy(time=now))
-            if message.type == 'end_of_track':
-                break
-
-    messages.sort(key=lambda x: x.time)
-
-    return messages
-
-
 class MidiFile:
     def __init__(self, filename=None, type=1,
                  ticks_per_beat=DEFAULT_TICKS_PER_BEAT,
@@ -352,28 +331,51 @@ class MidiFile:
         #
         return (tempo / 1000000.0) / self.ticks_per_beat
 
-    def __iter__(self):
+    def get_messages(self):
+        """Returns a list of all messages in all tracks.
+
+        The messages are returned in playback order with delta times
+        as if they were all in one track.
+
+        Will raise ValueError if the file is type 2 (asyncronous).
+        """
         # The tracks of type 2 files are not in sync, so they can
         # not be played back like this.
         if self.type == 2:
-            raise TypeError('type 2 file can not be played back like this')
+            raise TypeError("can't merge tracks in type 2 (asynchronous) file")
 
+        messages = []
+        for track in self.tracks:
+            now = 0
+            for message in track:
+                now += message.time
+                messages.append(message.copy(time=now))
+                if message.type == 'end_of_track':
+                    break
+
+        messages.sort(key=lambda x: x.time)
+
+        # Convert absolute time back to delta time.
+        last_time = 0
+        for message in messages:
+            message.time -= last_time
+            last_time += message.time
+
+        return messages
+
+    def __iter__(self):
         seconds_per_tick = self._get_seconds_per_tick(DEFAULT_TEMPO)
-        last_message_time = 0  # ticks
 
-        for message in _merge_tracks(self.tracks):
+        for message in self.get_messages():
             # Convert message time from absolute time
             # in ticks to relative time in seconds.
-            delta = message.time - last_message_time
-            if delta > 0:
-                message.time = delta * seconds_per_tick
+            if message.time > 0:
+                message.time *= seconds_per_tick
             else:
                 message.time = 0
 
             yield message       
 
-            last_message_time += delta
-
             if message.type == 'set_tempo':
                 seconds_per_tick = self._get_seconds_per_tick(message.tempo)
 
